@@ -58,10 +58,10 @@ namespace Aws
                  * Initializes TlsContextOptions with secure by default options, with
                  * no client certificates.
                  */
-                static TlsContextOptions InitDefaultClient(Allocator *allocator = g_allocator) noexcept;
+                static TlsContextOptions InitDefaultClient(Allocator *allocator = ApiAllocator()) noexcept;
 
                 /**
-                 * Initializes TlsContextOptions with secure by default options, with
+                 * Initializes TlsContextOptions for mutual TLS (mTLS), with
                  * client certificate and private key. These are paths to a file on disk. These files
                  * must be in the PEM format.
                  *
@@ -74,10 +74,10 @@ namespace Aws
                 static TlsContextOptions InitClientWithMtls(
                     const char *cert_path,
                     const char *pkey_path,
-                    Allocator *allocator = g_allocator) noexcept;
+                    Allocator *allocator = ApiAllocator()) noexcept;
 
                 /**
-                 * Initializes TlsContextOptions with secure by default options, with
+                 * Initializes TlsContextOptions for mutual TLS (mTLS), with
                  * client certificate and private key. These are in memory buffers. These buffers
                  * must be in the PEM format.
                  *
@@ -90,10 +90,10 @@ namespace Aws
                 static TlsContextOptions InitClientWithMtls(
                     const ByteCursor &cert,
                     const ByteCursor &pkey,
-                    Allocator *allocator = g_allocator) noexcept;
+                    Allocator *allocator = ApiAllocator()) noexcept;
 
                 /**
-                 * Initializes TlsContextOptions with secure by default options,
+                 * Initializes TlsContextOptions for mutual TLS (mTLS),
                  * using a PKCS#11 library for private key operations.
                  *
                  * NOTE: This only works on Unix devices.
@@ -103,11 +103,11 @@ namespace Aws
                  */
                 static TlsContextOptions InitClientWithMtlsPkcs11(
                     const TlsContextPkcs11Options &pkcs11Options,
-                    Allocator *allocator = g_allocator) noexcept;
+                    Allocator *allocator = ApiAllocator()) noexcept;
 
                 /**
-                 * Initializes TlsContextOptions with secure by default options, with
-                 * client certificateand private key in the PKCS#12 format.
+                 * Initializes TlsContextOptions for mutual TLS (mTLS), with
+                 * client certificate and private key in the PKCS#12 format.
                  *
                  * NOTE: This only works on Apple devices.
                  *
@@ -120,9 +120,11 @@ namespace Aws
                 static TlsContextOptions InitClientWithMtlsPkcs12(
                     const char *pkcs12_path,
                     const char *pkcs12_pwd,
-                    Allocator *allocator = g_allocator) noexcept;
+                    Allocator *allocator = ApiAllocator()) noexcept;
 
                 /**
+                 * @deprecated Custom keychain management is deprecated.
+                 *
                  * By default the certificates and private keys are stored in the default keychain
                  * of the account of the process. If you instead wish to provide your own keychain
                  * for storing them, this makes the TlsContext to use that instead.
@@ -133,16 +135,19 @@ namespace Aws
                 bool SetKeychainPath(ByteCursor &keychain_path) noexcept;
 
                 /**
-                 * Initializes options for use with mutual tls in client mode.
+                 * Initializes TlsContextOptions for mutual TLS (mTLS),
+                 * using a client certificate in a Windows certificate store.
                  *
                  * NOTE: This only works on Windows.
                  *
-                 * @param registryPath Path to a system installed certficate/private key pair.
-                 * Example: "CurrentUser\\MY\\<thumprint>"
+                 * @param windowsCertStorePath Path to certificate in a Windows certificate store.
+                 *    The path must use backslashes and end with the certificate's thumbprint.
+                 *    Example: `CurrentUser\MY\A11F8A9B5DF5B98BA3508FBCA575D09570E0D2C6`
+                 * @param allocator The memory allocator to use.
                  */
                 static TlsContextOptions InitClientWithMtlsSystemPath(
-                    const char *registryPath,
-                    Allocator *allocator = g_allocator) noexcept;
+                    const char *windowsCertStorePath,
+                    Allocator *allocator = ApiAllocator()) noexcept;
 
                 /**
                  * @return true if alpn is supported by the underlying security provider, false
@@ -211,7 +216,7 @@ namespace Aws
                  */
                 TlsContextPkcs11Options(
                     const std::shared_ptr<Pkcs11Lib> &pkcs11Lib,
-                    Allocator *allocator = g_allocator) noexcept;
+                    Allocator *allocator = ApiAllocator()) noexcept;
 
                 /**
                  * Use this PIN to log the user into the PKCS#11 token.
@@ -339,7 +344,7 @@ namespace Aws
             {
               public:
                 TlsContext() noexcept;
-                TlsContext(TlsContextOptions &options, TlsMode mode, Allocator *allocator = g_allocator) noexcept;
+                TlsContext(TlsContextOptions &options, TlsMode mode, Allocator *allocator = ApiAllocator()) noexcept;
                 ~TlsContext() = default;
                 TlsContext(const TlsContext &) noexcept = default;
                 TlsContext &operator=(const TlsContext &) noexcept = default;
@@ -393,7 +398,7 @@ namespace Aws
                 TlsChannelHandler(
                     struct aws_channel_slot *slot,
                     const struct aws_tls_connection_options &options,
-                    Allocator *allocator = g_allocator);
+                    Allocator *allocator = ApiAllocator());
 
                 /**
                  * Invoke this function from inside your handler after TLS negotiation completes. errorCode ==
@@ -429,7 +434,7 @@ namespace Aws
                 ClientTlsChannelHandler(
                     struct aws_channel_slot *slot,
                     const struct aws_tls_connection_options &options,
-                    Allocator *allocator = g_allocator);
+                    Allocator *allocator = ApiAllocator());
             };
 
             using NewClientTlsHandlerCallback = std::function<std::shared_ptr<ClientTlsChannelHandler>(
